package tk.glover.jsfunittest.entity.dbhelper;

import java.math.BigDecimal;
import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.Query;

import org.apache.commons.lang.StringUtils;
import org.jboss.seam.annotations.AutoCreate;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Name;

import tk.glover.jsfunittest.model.Suburbs;

/**
 * The Class DBHelperEntityImpl.
 * 
 * @author andrew glover
 */
@Stateless
@AutoCreate
@SuppressWarnings("unchecked")
@Name("dbHelperEntity")
public class DBHelperEntityImpl implements DBHelperEntity {

    /** entity manager. */
    @In
    private EntityManager em;

    /** {@inheritDoc} */
    @Override
    public List<Suburbs> autocompletePostcode(String postcode) throws Exception {
        String sql = " from Suburbs where id.postcode like :postcode";
        Query q = em.createQuery(sql);
        q.setParameter("postcode", StringUtils.trimToEmpty(postcode).toUpperCase() + "%");
        List<Suburbs> results = q.getResultList();
        return results;
    }

    /** {@inheritDoc} */
    @Override
    public List<Suburbs> autocompleteSuburb(String suburb) throws Exception {
        String sql = "from Suburbs where id.suburb like :suburb";
        Query q = em.createQuery(sql);
        q.setParameter("suburb", StringUtils.trimToEmpty(suburb).toUpperCase() + "%");
        List<Suburbs> results = q.getResultList();
        return results;
    }

    /** {@inheritDoc} */
    @Override
    public boolean validateStateSuburbPostcode(String state, String suburb, String postcode) {
        StringBuffer sql = new StringBuffer("select 1 FROM Suburbs WHERE id.postcode = :postcode AND state = :state ");
        sql.append("AND trim(id.suburb) = :suburb");

        Query query = em.createQuery(sql.toString()).setParameter("state", state).setParameter("suburb", suburb).setParameter("postcode", postcode);
        return !query.getResultList().isEmpty();
    }

    /** {@inheritDoc} */
    @Override
    public Long getNextSequence(String seqName) {
        return 1L;
    }

    /** {@inheritDoc} */
    @Override
    public EntityManager getEm() {
        return em;
    }

    @Override
    public void refresh(Object obj) {
        em.refresh(obj);
    }

}
