package tk.glover.jsfunittest.model;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Embeddable;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import org.apache.commons.lang.StringUtils;
import org.hibernate.validator.Length;

/**
 * The Class AddressSub.
 * @author andrew glover
 */
@Embeddable
public class AddressSub implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 8664085160885244139L;

    /** The start date. */
    @Column(name = "addr_start_date", nullable = false)
    @Temporal(TemporalType.DATE)
    private Date startDate;

    /** The street number. */
    @Column(name = "addr_street_num")
    @Length(max = 10)
    private String streetNumber;

    /** The street name. */
    @Column(name = "addr_street_name")
    @Length(max = 50)
    private String streetName;

    /** The street type. */
    @Column(name = "street_type")
    @Length(max = 6)
    private String streetType; // FK

    /** The town. */
    @Column(name = "addr_town_name")
    @Length(max = 50)
    private String town;

    /** The postcode. */
    @Column(name = "addr_postcode")
    @Length(max = 10)
    private String postcode;

    /** The state. */
    @Column(name = "addr_state")
    @Length(max = 3)
    private String state;

    /** The country. */
    @Column(name = "addr_country")
    @Length(max = 30)
    private String country;

    /**
     * Instantiates a new address sub.
     */
    public AddressSub() {
        this.startDate = new Date();
    }

    public String toString() {
        StringBuffer buff = new StringBuffer();

        buff.append(this.getStreetNumber() + " " + this.getStreetName() + " " + this.getStreetType() + " " + this.getTown() + " " + this.getState()
                        + " " + this.getPostcode());
        return buff.toString();
    }

    /**
     * Gets the street number.
     * 
     * @return the street number
     */
    public String getStreetNumber() {
        return StringUtils.trimToEmpty(streetNumber);
    }

    /**
     * Sets the street number.
     * 
     * @param streetNumber
     *            the new street number
     */
    public void setStreetNumber(String streetNumber) {
        this.streetNumber = StringUtils.trimToEmpty(streetNumber);
        this.streetNumber = StringUtils.capitalize(streetNumber);
    }

    /**
     * Gets the street name.
     * 
     * @return the street name
     */
    public String getStreetName() {
        return StringUtils.trimToEmpty(streetName);
    }

    /**
     * Sets the street name.
     * 
     * @param streetName
     *            the new street name
     */
    public void setStreetName(String streetName) {
        this.streetName = StringUtils.trimToEmpty(streetName);
        this.streetName = StringUtils.capitalize(streetName);
    }

    /**
     * Gets the street type.
     * 
     * @return the street type
     */
    public String getStreetType() {
        return StringUtils.trimToEmpty(streetType);
    }

    /**
     * Sets the street type.
     * 
     * @param streetType
     *            the new street type
     */
    public void setStreetType(String streetType) {
        this.streetType = streetType;
    }

    /**
     * Gets the town.
     * 
     * @return the town
     */
    public String getTown() {
        return StringUtils.trimToEmpty(town);
    }

    /**
     * Sets the town.
     * 
     * @param town
     *            the new town
     */
    public void setTown(String town) {
        this.town = StringUtils.trimToEmpty(town);
        this.town = StringUtils.capitalize(town);
    }

    /**
     * Gets the postcode.
     * 
     * @return the postcode
     */
    public String getPostcode() {
        return StringUtils.trimToEmpty(postcode);
    }

    /**
     * Sets the postcode.
     * 
     * @param postcode
     *            the new postcode
     */
    public void setPostcode(String postcode) {
        this.postcode = postcode;
    }

    /**
     * Gets the state.
     * 
     * @return the state
     */
    public String getState() {
        return StringUtils.trimToEmpty(state);
    }

    /**
     * Sets the state.
     * 
     * @param state
     *            the new state
     */
    public void setState(String state) {
        this.state = StringUtils.trimToEmpty(state);
        this.state = StringUtils.capitalize(state);
    }

    /**
     * Gets the country.
     * 
     * @return the country
     */
    public String getCountry() {
        return StringUtils.trimToEmpty(country);
    }

    /**
     * Sets the country.
     * 
     * @param country
     *            the new country
     */
    public void setCountry(String country) {
        this.country = StringUtils.trimToEmpty(country);
        this.country = StringUtils.capitalize(country);
    }

    /**
     * Gets the start date.
     * 
     * @return the start date
     */
    public Date getStartDate() {
        return startDate;
    }

    /**
     * Sets the start date.
     * 
     * @param startDate
     *            the new start date
     */
    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((country == null) ? 0 : country.hashCode());
        result = prime * result + ((postcode == null) ? 0 : postcode.hashCode());
        result = prime * result + ((startDate == null) ? 0 : startDate.hashCode());
        result = prime * result + ((state == null) ? 0 : state.hashCode());
        result = prime * result + ((streetName == null) ? 0 : streetName.hashCode());
        result = prime * result + ((streetNumber == null) ? 0 : streetNumber.hashCode());
        result = prime * result + ((streetType == null) ? 0 : streetType.hashCode());
        result = prime * result + ((town == null) ? 0 : town.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        AddressSub other = (AddressSub) obj;
        if (country == null) {
            if (other.country != null) {
                return false;
            }
        } else if (!country.equals(other.country)) {
            return false;
        }
        if (postcode == null) {
            if (other.postcode != null) {
                return false;
            }
        } else if (!postcode.equals(other.postcode)) {
            return false;
        }
        if (startDate == null) {
            if (other.startDate != null) {
                return false;
            }
        } else if (!startDate.equals(other.startDate)) {
            return false;
        }
        if (state == null) {
            if (other.state != null) {
                return false;
            }
        } else if (!state.equals(other.state)) {
            return false;
        }
        if (streetName == null) {
            if (other.streetName != null) {
                return false;
            }
        } else if (!streetName.equals(other.streetName)) {
            return false;
        }
        if (streetNumber == null) {
            if (other.streetNumber != null) {
                return false;
            }
        } else if (!streetNumber.equals(other.streetNumber)) {
            return false;
        }
        if (streetType == null) {
            if (other.streetType != null) {
                return false;
            }
        } else if (!streetType.equals(other.streetType)) {
            return false;
        }
        if (town == null) {
            if (other.town != null) {
                return false;
            }
        } else if (!town.equals(other.town)) {
            return false;
        }
        return true;
    }
}
