package tk.glover.jsfunittest.model;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Embeddable;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.Table;

import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;
import org.hibernate.annotations.Type;

/**
 * Suburbs entity.
 * 
 * @author andrew glover
 */
@Entity
@Table(name = "jsfUnitTestSuburbs")
@Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class Suburbs implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 1480182982669431754L;

    /** The id. */
    @EmbeddedId
    private SuburbId id;

    /** The state. */
    @Column(name = "suburb_state")
    private String state;

    /** The psl area. */
    @Column(name = "suburb_psl_area")
    private String pslArea;

    /** The include for stamp duties. */
    @Column(name = "suburb_inc_for_stamp_duties")
    @Type(type = "org.hibernate.type.YesNoType")
    private Boolean includeForStampDuties;

    /** The default postcode. */
    @Column(name = "suburb_dflt_postcode")
    @Type(type = "org.hibernate.type.YesNoType")
    private Boolean defaultPostcode;

    /**
     * Gets the id.
     * 
     * @return the id
     */
    public SuburbId getId() {
        return id;
    }

    /**
     * Sets the id.
     * 
     * @param id
     *            the new id
     */
    public void setId(SuburbId id) {
        this.id = id;
    }

    /**
     * Gets the state.
     * 
     * @return the state
     */
    public String getState() {
        return state;
    }

    /**
     * Sets the state.
     * 
     * @param state
     *            the new state
     */
    public void setState(String state) {
        this.state = state;
    }

    /**
     * Gets the include for stamp duties.
     * 
     * @return the include for stamp duties
     */
    public Boolean getIncludeForStampDuties() {
        return includeForStampDuties;
    }

    /**
     * Sets the include for stamp duties.
     * 
     * @param includeForStampDuties
     *            the new include for stamp duties
     */
    public void setIncludeForStampDuties(Boolean includeForStampDuties) {
        this.includeForStampDuties = includeForStampDuties;
    }

    /**
     * Gets the default postcode.
     * 
     * @return the default postcode
     */
    public Boolean getDefaultPostcode() {
        return defaultPostcode;
    }

    /**
     * Sets the default postcode.
     * 
     * @param defaultPostcode
     *            the new default postcode
     */
    public void setDefaultPostcode(Boolean defaultPostcode) {
        this.defaultPostcode = defaultPostcode;
    }

    /**
     * Gets the psl area.
     * 
     * @return the psl area
     */
    public String getPslArea() {
        return pslArea;
    }

    /**
     * Sets the psl area.
     * 
     * @param pslArea
     *            the new psl area
     */
    public void setPslArea(String pslArea) {
        this.pslArea = pslArea;
    }

    /**
     * Instantiates a new suburbs.
     */
    public Suburbs() {
        super();
    }

    /**
     * The Class SuburbId.
     */
    @Embeddable
    public static class SuburbId implements Serializable {

        /** The Constant serialVersionUID. */
        private static final long serialVersionUID = -8937279838774004913L;

        /** The suburb. */
        @Column(name = "suburb_town_name")
        private String suburb;

        /** The postcode. */
        @Column(name = "suburb_postcode")
        private String postcode;

        /**
         * Gets the suburb.
         * 
         * @return the suburb
         */
        public String getSuburb() {
            return suburb;
        }

        /**
         * Sets the suburb.
         * 
         * @param suburb
         *            the new suburb
         */
        public void setSuburb(String suburb) {
            this.suburb = suburb;
        }

        /**
         * Gets the postcode.
         * 
         * @return the postcode
         */
        public String getPostcode() {
            return postcode;
        }

        /**
         * Sets the postcode.
         * 
         * @param postcode
         *            the new postcode
         */
        public void setPostcode(String postcode) {
            this.postcode = postcode;
        }

        @Override
        public int hashCode() {
            final int prime = 31;
            int result = 1;
            result = prime * result + ((postcode == null) ? 0 : postcode.hashCode());
            result = prime * result + ((suburb == null) ? 0 : suburb.hashCode());
            return result;
        }

        @Override
        public boolean equals(Object obj) {
            if (this == obj)
                return true;
            if (obj == null)
                return false;
            if (getClass() != obj.getClass())
                return false;
            SuburbId other = (SuburbId) obj;
            if (postcode == null) {
                if (other.postcode != null)
                    return false;
            } else if (!postcode.equals(other.postcode))
                return false;
            if (suburb == null) {
                if (other.suburb != null)
                    return false;
            } else if (!suburb.equals(other.suburb))
                return false;
            return true;
        }

    }

}