package tk.glover.jsfunittest.service;

import java.util.List;

import javax.ejb.Local;

import tk.glover.jsfunittest.model.Suburbs;

/**
 * The Interface DBHelperService.
 * 
 * @author andrew glover
 */
@Local
public interface DBHelperService {

    /**
     * Find list of SuburbSearchResult - containing suburb and postcode list - where its suburb name starts with the given 'suburb' input. This method
     * is used in suburb/postcode auto completion widget
     * 
     * @param suburb
     *            the suburb
     * 
     * @return list of SuburbSearchResult
     * 
     * @throws Exception
     *             the exception
     */
    public List<Suburbs> autocompleteSuburb(String suburb) throws Exception;

    /**
     * Find list of SuburbSearchResult - containing suburb and postcode list - where its postcode starts with the given 'postcode' input. This method
     * is used in suburb/postcode auto completion widget
     * 
     * @param postcode
     *            the postcode
     * 
     * @return list of SuburbSearchResult
     * 
     * @throws Exception
     *             the exception
     */
    public List<Suburbs> autocompletePostcode(String postcode) throws Exception;

    /**
     * Validate suburb and postcode.
     * 
     * @param suburb
     *            the suburb
     * @param postcode
     *            the postcode
     * @param state
     *            the state
     * 
     * @return true if valid. false otherwise
     */
    public boolean validateStateSuburbPostcode(String state, String suburb, String postcode);

    /**
     * Gets the next sequence.
     * 
     * @param seqName
     *            the seq name
     * 
     * @return the next sequence
     */
    public Long getNextSequence(String seqName);

    /**
     * Flush em.
     */
    public void flush();

    /**
     * Refresh.
     * 
     * @param obj
     *            the obj
     */
    public void refresh(Object obj);

}
