package tk.glover.jsfunittest.session;

import java.io.Serializable;

import org.apache.commons.lang.StringUtils;
import org.hibernate.util.SerializationHelper;
import org.jboss.seam.ScopeType;
import org.jboss.seam.annotations.AutoCreate;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.annotations.Scope;
import org.jboss.seam.core.Conversation;
import org.jboss.seam.international.StatusMessage;
import org.jboss.seam.international.StatusMessages;
import org.jboss.seam.international.StatusMessage.Severity;

import tk.glover.jsfunittest.model.Address;
import tk.glover.jsfunittest.service.DBHelperService;

/**
 * The Class AddressAction.
 * 
 * @author andrew glover
 */
@Name("address")
@Scope(ScopeType.CONVERSATION)
@AutoCreate
public class AddressAction implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -7231049299541461330L;

    /** The mars config. */
    @In
    private ProjectConfig projectConfig;

    /** The delete popup. */
    @In
    private DeletePopupBacking deletePopup;

    /** The db helper service. */
    @In
    private DBHelperService dbHelperService;

    /** The status messages. */
    @In
    private StatusMessages statusMessages;

    /** The edit mode. */
    private boolean editMode;

    /** The address. */
    private Address address;

    /** The original address. */
    private Address originalAddress;

    /**
     * Prepare for address registration.
     * 
     * @return the string
     */
    public String manageAddress() {
        originalAddress = (Address) SerializationHelper.clone(address);
        return "manage_address";
    }

    /**
     * Inits the address.
     */
    private void initAddress() {
        address = new Address();
        address.setId(1L);
    }

    /**
     * Adds the address.
     */
    public void addNewAddress() {
        this.editMode = false;
        initAddress();
    }

    /**
     * Sets the up edit address.
     * 
     * @param address
     *            the new up edit address
     */
    public void prepareEdit(Address address) {
        this.editMode = true;
        this.address = address;
        this.originalAddress = new Address();
        this.originalAddress.copyAttributesFrom(address);
    }

    /**
     * Cancel current action and back to previous page.
     * 
     * @return the view id
     */
    public String cancel() {

        return "suggestionOnModalPanel";
    }


    /**
     * Cancel edit.
     */
    public void cancelEdit() {
        if (editMode) {
        }
    }

    /**
     * Save action on the manage page.
     * 
     * @return the string
     */
    public String saveToClient() {
        if (validateAddress()) {
            try {
                // save to db
                dbHelperService.flush();
                // end the nested conversation
                Conversation.instance().end();
                return "view_client";
            } catch (Exception e) {
                statusMessages.add(Severity.ERROR, e.getMessage());
                return null;
            }
        } else {
            return null;
        }
    }

    /**
     * Save create/edit from pop up.
     */
    public void saveEdit() {
        if (validateAddress()) {
            if (editMode) {
            }
        }
    }

    /**
     * Sets address to be deleted.
     * 
     * @param address
     *            to be deleted
     */
    public void prepareDelete(Address address) {
        this.address = address;
        this.deletePopup.setTitle("Address");
        this.deletePopup.setDeleteLabel(address.toString());
        this.deletePopup.setYesCallback("#{clientRegnAddress.removeFromClient}");
        this.deletePopup.setReRenderIds("address_view");
    }

    /**
     * Validate address.
     * 
     * @return true, if successful
     */
    private boolean validateAddress() {
        boolean result = true;

        if (StringUtils.isBlank(address.getAddressSub().getStreetNumber())) {
            statusMessages.addToControlFromResourceBundle("l_box", StatusMessage.Severity.ERROR, "field.empty");
            result = false;
        }
        if (StringUtils.isBlank(address.getAddressSub().getStreetName())) {
            statusMessages.addToControlFromResourceBundle("l_street_name", StatusMessage.Severity.ERROR, "field.empty");
            result = false;
        }

        if (StringUtils.isBlank(address.getAddressSub().getTown())) {
            statusMessages.addToControlFromResourceBundle("x_location", StatusMessage.Severity.ERROR, "field.empty");
            result = false;
        }

        return result;
    }

    /**
     * Checks if is edits the mode.
     * 
     * @return true, if is edits the mode
     */
    public boolean isEditMode() {
        return editMode;
    }

    /**
     * Sets the edits the mode.
     * 
     * @param editMode
     *            the new edits the mode
     */
    public void setEditMode(boolean editMode) {
        this.editMode = editMode;
    }

    /**
     * Gets the address.
     * 
     * @return the address
     */
    public Address getAddress() {
        return address;
    }

    /**
     * Sets the address.
     * 
     * @param address
     *            the new address
     */
    public void setAddress(Address address) {
        this.address = address;
    }

}
