package tk.glover.jsfunittest.session;

import java.io.Serializable;
import java.util.List;

import org.jboss.seam.ScopeType;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.annotations.Observer;
import org.jboss.seam.annotations.Scope;

import tk.glover.jsfunittest.model.Suburbs;
import tk.glover.jsfunittest.service.DBHelperService;

/**
 * The Class ProjectConfig.
 * 
 * @author andrew glover
 */
@Name("projectConfig")
@Scope(ScopeType.APPLICATION)
public class ProjectConfig implements Serializable {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = -7299413060394531654L;

    /** The db service. */
    @In
    private DBHelperService dbHelperService;

    /**
     * Load CgRefCodes list.
     */
    @Observer("org.jboss.seam.postInitialization")
    public void initialise() {

    }

    /**
     * Autocomplete suburb.
     * 
     * @param suburb
     *            the suburb
     * 
     * @return the list< suburb search result>
     * 
     * @throws Exception
     *             the exception
     */
    public List<Suburbs> autocompleteSuburb(Object suburb) throws Exception {
        return dbHelperService.autocompleteSuburb((String) suburb);
    }

    /**
     * Autocomplete postcode.
     * 
     * @param postcode
     *            the postcode
     * 
     * @return the list< suburb search result>
     * 
     * @throws Exception
     *             the exception
     */
    public List<Suburbs> autocompletePostcode(Object postcode) throws Exception {
        return dbHelperService.autocompletePostcode((String) postcode);
    }

    /**
     * Validate state suburb postcode.
     * 
     * @param state
     *            the state
     * @param suburb
     *            the suburb
     * @param postcode
     *            the postcode
     * 
     * @return true, if successful
     */
    public boolean validateStateSuburbPostcode(String state, String suburb, String postcode) {
        return dbHelperService.validateStateSuburbPostcode(state, suburb, postcode);
    }

    /**
     * Gets the version.
     * 
     * @return the version
     */
    public String getVersion() {
        return "unversioned!";
    }
}
