package tk.glover.jsfUnitTest.test;

import java.io.IOException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jboss.jsfunit.jsfsession.JSFClientSession;
import org.jboss.jsfunit.jsfsession.JSFServerSession;
import org.jboss.jsfunit.jsfsession.JSFSession;
import org.jboss.jsfunit.richclient.RichFacesClient;

/**
 * @author andrew
 * 
 */
public abstract class BaseTest extends org.apache.cactus.ServletTestCase {
    /** Log */
    private static final Log log = LogFactory.getLog(BaseTest.class);

    /** Send an HTTP request for the initial page */
    protected JSFSession jsfSession;

    /** A JSFClientSession emulates the browser and lets you test HTML */
    protected JSFClientSession jsfClientSession;

    /** A RichFacesClient emulates the browser and lets you test ajax */
    protected RichFacesClient richFacesClient;

    /** A JSFServerSession gives you access to JSF state */
    protected JSFServerSession jsfServerSession;

    /** Get the name of the test case class */
    public final String className = this.getClass().getSimpleName();

    /** Login to the application and check that login has worked */
    public void setUp() {
        try {
            /** get the method name */
            String testName = className + ":" + this.getName() + " - ";

            // Send an HTTP request for the initial page
            jsfSession = new JSFSession("/login.seam");

            // A JSFClientSession emulates the browser and lets you test HTML
            jsfClientSession = jsfSession.getJSFClientSession();

            // A JSFServerSession gives you access to JSF state
            jsfServerSession = jsfSession.getJSFServerSession();

            richFacesClient = new RichFacesClient(jsfClientSession);

            jsfClientSession.setValue("username", "admin");
            jsfClientSession.setValue("password", "admin");
            jsfClientSession.click("m3_submit");
            Object userBeanValue = jsfServerSession.getManagedBeanValue("#{identity.username}");

            assertEquals(testName + "Invalid user found", "admin", userBeanValue);
            String textRequired = "Welcome to Seam!";
            assertTrue(testName + "Text not found on page - " + textRequired, jsfClientSession.getPageAsText().contains(textRequired));

            log.info("Logged in as " + userBeanValue);
        } catch (IOException e) {
            log.error("Login has failed", e);
        }
    }

    /** Can't logout here as any error in a test will call tear down, if this has an error then this will be the one reported on. */
    public void tearDown() {
    }
}
